@@ -199,4 +199,9 @@ def list_union(a,b):
     return list(set(a).union(set(b)))
 
 def list_dif(a,b):
-    return list(set(b).difference(set(a)))
\ No newline at end of file
+    return list(set(b).difference(set(a)))
+
+
+def swapPositions(list, pos1, pos2):
+    list[pos1], list[pos2] = list[pos2], list[pos1]
+    return list
\ No newline at end of file
